Index: kernel/arch/ia32/src/asm.S
===================================================================
--- kernel/arch/ia32/src/asm.S	(revision af863d0df32b98f1005d2470e2de1d3e71a445e6)
+++ kernel/arch/ia32/src/asm.S	(revision 9fcdb2e47bf10ab0360bec803e2a1699dbf56f42)
@@ -72,5 +72,5 @@
  * @param MEMCPY_SIZE(%esp)	Size.
  *
  * @return MEMCPY_SRC(%esp) on success and 0 on failure.
  */
 memcpy:
@@ -97,5 +97,5 @@
 	movl %edx, %edi
 	movl %eax, %esi
-	movl MEMCPY_SRC(%esp), %eax	/* MEMCPY_SRC(%esp), success */
+	movl MEMCPY_DST(%esp), %eax	/* MEMCPY_DST(%esp), success */
 	ret
 	
@@ -72,5 +72,5 @@
  * @param MEMCPY_SIZE(%esp)	Size.
  *
- * @return MEMCPY_SRC(%esp) on success and 0 on failure.
+ * @return MEMCPY_DST(%esp) on success and 0 on failure.
  */
 memcpy:
